==> zio-aws-ec2_2.13-5.17.125.1-sources.jar: zio/aws/ec2/model/DeleteTransitGatewayResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DeleteTransitGatewayResponse(
    transitGateway: Option[zio.aws.ec2.model.TransitGateway] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DeleteTransitGatewayResponse = {
    import DeleteTransitGatewayResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DeleteTransitGatewayResponse
      .builder()
      .optionallyWith(transitGateway.map(value => value.buildAwsValue()))(
        _.transitGateway
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.DeleteTransitGatewayResponse.ReadOnly =
    zio.aws.ec2.model.DeleteTransitGatewayResponse.wrap(buildAwsValue())
}
object DeleteTransitGatewayResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DeleteTransitGatewayResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DeleteTransitGatewayResponse =
      zio.aws.ec2.model.DeleteTransitGatewayResponse(
        transitGateway.map(value => value.asEditable)
      )
    def transitGateway: Option[zio.aws.ec2.model.TransitGateway.ReadOnly]
    def getTransitGateway
        : ZIO[Any, AwsError, zio.aws.ec2.model.TransitGateway.ReadOnly] =
      AwsError.unwrapOptionField("transitGateway", transitGateway)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DeleteTransitGatewayResponse
  ) extends zio.aws.ec2.model.DeleteTransitGatewayResponse.ReadOnly {
    override val transitGateway
        : Option[zio.aws.ec2.model.TransitGateway.ReadOnly] = scala
      .Option(impl.transitGateway())
      .map(value => zio.aws.ec2.model.TransitGateway.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DeleteTransitGatewayResponse
  ): zio.aws.ec2.model.DeleteTransitGatewayResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.13-6.20.58.3-sources.jar: zio/aws/ec2/model/DeleteTransitGatewayResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DeleteTransitGatewayResponse(
    transitGateway: Optional[zio.aws.ec2.model.TransitGateway] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DeleteTransitGatewayResponse = {
    import DeleteTransitGatewayResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DeleteTransitGatewayResponse
      .builder()
      .optionallyWith(transitGateway.map(value => value.buildAwsValue()))(
        _.transitGateway
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.DeleteTransitGatewayResponse.ReadOnly =
    zio.aws.ec2.model.DeleteTransitGatewayResponse.wrap(buildAwsValue())
}
object DeleteTransitGatewayResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DeleteTransitGatewayResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DeleteTransitGatewayResponse =
      zio.aws.ec2.model.DeleteTransitGatewayResponse(
        transitGateway.map(value => value.asEditable)
      )
    def transitGateway: Optional[zio.aws.ec2.model.TransitGateway.ReadOnly]
    def getTransitGateway
        : ZIO[Any, AwsError, zio.aws.ec2.model.TransitGateway.ReadOnly] =
      AwsError.unwrapOptionField("transitGateway", transitGateway)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DeleteTransitGatewayResponse
  ) extends zio.aws.ec2.model.DeleteTransitGatewayResponse.ReadOnly {
    override val transitGateway
        : Optional[zio.aws.ec2.model.TransitGateway.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.transitGateway())
        .map(value => zio.aws.ec2.model.TransitGateway.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DeleteTransitGatewayResponse
  ): zio.aws.ec2.model.DeleteTransitGatewayResponse.ReadOnly = new Wrapper(impl)
}
